@@ -7,7 +7,7 @@ use POSIX qw/ceil floor/;
 use Scalar::Util qw/blessed looks_like_number/;
 require Exporter;
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 our @ISA = 'Exporter';
 our @EXPORT_OK = 'calc';
 our $ERROR;
@@ -99,7 +99,11 @@ use constant ROUND_HALF => 0.50000000000008;
 	sub _default_functions { +{%functions} }
 	
 	my $singleton;
-	sub _instance { blessed $_[0] ? $_[0] : ($singleton //= $_[0]->new) }
+	sub _instance {
+		return $_[0] if blessed $_[0];
+		$singleton = $_[0]->new unless defined $singleton;
+		return $singleton;
+	}
 }
 
 sub new {
@@ -453,7 +457,7 @@ exception on failure.
     print "Error: $Math::Calc::Parser::ERROR\n";
   }
   
-  if (defined (my $result = $parser->evaluate('log(5')) {
+  if (defined (my $result = $parser->evaluate('log(5'))) {
   	print "Result: $result\n";
   } else {
   	print "Error: ".$parser->error."\n";
